# django-raise

Models and views to support collecting pledge to raise funds with
rewards to people who make pledges.

Developed under Python 3.6 and Django 2.0. Pull request to support other
versions welcome.
